import { Component, OnInit } from '@angular/core';
import { FormArray, FormBuilder, FormGroup } from '@angular/forms';

@Component({
  selector: 'app-veriable-form',
  templateUrl: './veriable-form.component.html',
  styleUrls: ['./veriable-form.component.sass']
})
export class VeriableFormComponent implements OnInit {
  form: FormGroup;

  // Sample variable list for dropdown
  variableList = ['Variable 1', 'Variable 2', 'Variable 3'];

  constructor(private fb: FormBuilder) {
    this.form = this.fb.group({
      rows: this.fb.array([]) // Form array for multiple rows
    });
  }

  ngOnInit(): void {
    // Initialize with one row
    this.addRow();
  }

  get rows(): FormArray {
    return this.form.get('rows') as FormArray;
  }

  getColumns(row: any): FormArray {
    return row.get('columns') as FormArray;
  }

  isText(row: any, colIndex: number): boolean {
    const columns = this.getColumns(row);
    return columns.at(colIndex).get('type')?.value === 'text';
  }

  isVariable(row: any, colIndex: number): boolean {
    const columns = this.getColumns(row);
    return columns.at(colIndex).get('type')?.value === 'variable';
  }

  createColumn(): FormGroup {
    return this.fb.group({
      type: [''], // Type can be 'text' or 'variable'
      textValue: [''], // For text input
      variableValue: [''] // For variable select
    });
  }

  addColumn(rowIndex: number): void {
    const row = this.rows.at(rowIndex).get('columns') as FormArray;
    row.push(this.createColumn());
  }

  addRow(): void {
    const row = this.fb.group({
      columns: this.fb.array([this.createColumn()]) // Initialize with one column
    });
    this.rows.push(row);
  }

  onSubmit(): void {
    console.log(this.form.value);
  }
}
